@@ -146,9 +146,8 @@ _bson_error_message_printf (bson_error_t *error, const char *format, ...)
    }
 }
 
-#define RUN_CMD_ERR(_domain, _code, _msg)                          \
+#define RUN_CMD_ERR_DECORATE                                       \
    do {                                                            \
-      bson_set_error (error, _domain, _code, _msg);                \
       _bson_error_message_printf (                                 \
          error,                                                    \
          "Failed to send \"%s\" command with database \"%s\": %s", \
@@ -157,6 +156,11 @@ _bson_error_message_printf (bson_error_t *error, const char *format, ...)
          error->message);                                          \
    } while (0)
 
+#define RUN_CMD_ERR(_domain, _code, ...)                   \
+   do {                                                    \
+      bson_set_error (error, _domain, _code, __VA_ARGS__); \
+      RUN_CMD_ERR_DECORATE;                                \
+   } while (0)
 
 /*
  *--------------------------------------------------------------------------
@@ -259,13 +263,7 @@ mongoc_cluster_run_command_opquery (mongoc_cluster_t *cluster,
       mongoc_cluster_disconnect_node (cluster, server_id, true, error);
 
       /* add info about the command to writev_full's error message */
-      _bson_error_message_printf (
-         error,
-         "Failed to send \"%s\" command with database \"%s\": %s",
-         cmd->command_name,
-         cmd->db_name,
-         error->message);
-
+      RUN_CMD_ERR_DECORATE;
       GOTO (done);
    }
 
@@ -625,12 +623,12 @@ static mongoc_server_description_t *
 _mongoc_stream_run_ismaster (mongoc_cluster_t *cluster,
                              mongoc_stream_t *stream,
                              const char *address,
-                             uint32_t server_id)
+                             uint32_t server_id,
+                             bson_error_t *error)
 {
    const bson_t *command;
    mongoc_cmd_parts_t parts;
    bson_t reply;
-   bson_error_t error;
    int64_t start;
    int64_t rtt_msec;
    mongoc_server_description_t *sd;
@@ -647,7 +645,7 @@ _mongoc_stream_run_ismaster (mongoc_cluster_t *cluster,
 
    start = bson_get_monotonic_time ();
    server_stream = _mongoc_cluster_create_server_stream (
-      cluster->client->topology, server_id, stream, &error);
+      cluster->client->topology, server_id, stream, error);
    if (!server_stream) {
       RETURN (NULL);
    }
@@ -656,7 +654,8 @@ _mongoc_stream_run_ismaster (mongoc_cluster_t *cluster,
       &parts, cluster->client, "admin", MONGOC_QUERY_SLAVE_OK, command);
    parts.prohibit_lsid = true;
    if (!mongoc_cluster_run_command_parts (
-          cluster, server_stream, &parts, &reply, &error)) {
+      cluster, server_stream, &parts, &reply, error)) {
+      bson_destroy (&reply);
       mongoc_server_stream_cleanup (server_stream);
       RETURN (NULL);
    }
@@ -668,7 +667,7 @@ _mongoc_stream_run_ismaster (mongoc_cluster_t *cluster,
 
    mongoc_server_description_init (sd, address, server_id);
    /* send the error from run_command IN to handle_ismaster */
-   mongoc_server_description_handle_ismaster (sd, &reply, rtt_msec, &error);
+   mongoc_server_description_handle_ismaster (sd, &reply, rtt_msec, error);
 
    bson_destroy (&reply);
 
@@ -719,7 +718,11 @@ _mongoc_cluster_run_ismaster (mongoc_cluster_t *cluster,
    BSON_ASSERT (node->stream);
 
    sd = _mongoc_stream_run_ismaster (
-      cluster, node->stream, node->connection_address, server_id);
+      cluster, node->stream, node->connection_address, server_id, error);
+
+   if (!sd) {
+      return NULL;
+   }
 
    if (sd->type == MONGOC_SERVER_UNKNOWN) {
       memcpy (error, &sd->error, sizeof (bson_error_t));
@@ -1738,7 +1741,7 @@ mongoc_cluster_fetch_stream_single (mongoc_cluster_t *cluster,
 #endif
 
       sd = _mongoc_stream_run_ismaster (
-         cluster, stream, scanner_node->host.host_and_port, server_id);
+         cluster, stream, scanner_node->host.host_and_port, server_id, error);
 
       if (!sd) {
          return NULL;
@@ -2574,6 +2577,8 @@ mongoc_cluster_run_opmsg (mongoc_cluster_t *cluster,
                                     cluster->sockettimeoutms,
                                     error);
    if (!ok) {
+      /* add info about the command to writev_full's error message */
+      RUN_CMD_ERR_DECORATE;
       mongoc_cluster_disconnect_node (
          cluster, server_stream->sd->id, true, error);
       bson_free (output);
@@ -2585,6 +2590,7 @@ mongoc_cluster_run_opmsg (mongoc_cluster_t *cluster,
    ok = _mongoc_buffer_append_from_stream (
       &buffer, server_stream->stream, 4, cluster->sockettimeoutms, error);
    if (!ok) {
+         RUN_CMD_ERR_DECORATE;
       mongoc_cluster_disconnect_node (
          cluster, server_stream->sd->id, true, error);
       bson_free (output);
@@ -2597,8 +2603,7 @@ mongoc_cluster_run_opmsg (mongoc_cluster_t *cluster,
    memcpy (&msg_len, buffer.data, 4);
    msg_len = BSON_UINT32_FROM_LE (msg_len);
    if ((msg_len < 16) || (msg_len > server_stream->sd->max_msg_size)) {
-      bson_set_error (
-         error,
+         RUN_CMD_ERR (
          MONGOC_ERROR_PROTOCOL,
          MONGOC_ERROR_PROTOCOL_INVALID_REPLY,
          "Message size %d is not within expected range 16-%d bytes",
@@ -2618,6 +2623,7 @@ mongoc_cluster_run_opmsg (mongoc_cluster_t *cluster,
                                            cluster->sockettimeoutms,
                                            error);
    if (!ok) {
+         RUN_CMD_ERR_DECORATE;
       mongoc_cluster_disconnect_node (
          cluster, server_stream->sd->id, true, error);
       bson_free (output);
@@ -2628,8 +2634,7 @@ mongoc_cluster_run_opmsg (mongoc_cluster_t *cluster,
 
    ok = _mongoc_rpc_scatter (&rpc, buffer.data, buffer.len);
    if (!ok) {
-      bson_set_error (error,
-                      MONGOC_ERROR_PROTOCOL,
+         RUN_CMD_ERR (MONGOC_ERROR_PROTOCOL,
                       MONGOC_ERROR_PROTOCOL_INVALID_REPLY,
                       "Malformed message from server");
       bson_free (output);
@@ -2643,8 +2648,7 @@ mongoc_cluster_run_opmsg (mongoc_cluster_t *cluster,
 
       output = bson_realloc (output, len);
       if (!_mongoc_rpc_decompress (&rpc, (uint8_t *) output, len)) {
-         bson_set_error (error,
-                         MONGOC_ERROR_PROTOCOL,
+            RUN_CMD_ERR (MONGOC_ERROR_PROTOCOL,
                          MONGOC_ERROR_PROTOCOL_INVALID_REPLY,
                          "Could not decompress message from server");
          mongoc_cluster_disconnect_node (
