@@ -34,55 +34,69 @@ test_mongoc_client_max_staleness (void)
    ASSERT_CMPINT64 (get_max_staleness (client), ==, (int64_t) -1);
    mongoc_client_destroy (client);
 
-   client = mongoc_client_new ("mongodb://a/?readPreference=secondary");
+   client = mongoc_client_new ("mongodb://a/?" MONGOC_URI_READPREFERENCE
+                               "=secondary");
    ASSERT_CMPINT64 (get_max_staleness (client), ==, (int64_t) -1);
    mongoc_client_destroy (client);
 
    /* -1 is the default, means "no max staleness" */
-   client = mongoc_client_new ("mongodb://a/?maxStalenessSeconds=-1");
+   client =
+      mongoc_client_new ("mongodb://a/?" MONGOC_URI_MAXSTALENESSSECONDS "=-1");
    ASSERT_CMPINT64 (get_max_staleness (client), ==, (int64_t) -1);
    mongoc_client_destroy (client);
 
-   client = mongoc_client_new (
-      "mongodb://a/?readPreference=primary&maxStalenessSeconds=-1");
+   client =
+      mongoc_client_new ("mongodb://a/?" MONGOC_URI_READPREFERENCE
+                         "=primary&" MONGOC_URI_MAXSTALENESSSECONDS "=-1");
 
    ASSERT_CMPINT64 (get_max_staleness (client), ==, (int64_t) -1);
    mongoc_client_destroy (client);
 
-   /* no maxStalenessSeconds with primary mode */
-   ASSERT (!mongoc_client_new ("mongodb://a/?maxStalenessSeconds=120"));
-   ASSERT (!mongoc_client_new (
-              "mongodb://a/?readPreference=primary&maxStalenessSeconds=120"));
+   /* no " MONGOC_URI_MAXSTALENESSSECONDS " with primary mode */
+   capture_logs (true);
+   ASSERT (!mongoc_client_new ("mongodb://a/?" MONGOC_URI_MAXSTALENESSSECONDS
+                               "=120"));
+   ASSERT (!mongoc_client_new ("mongodb://a/?" MONGOC_URI_READPREFERENCE
+                               "=primary&" MONGOC_URI_MAXSTALENESSSECONDS
+                               "=120"));
+   ASSERT_CAPTURED_LOG (MONGOC_URI_MAXSTALENESSSECONDS "=120",
+                        MONGOC_LOG_LEVEL_WARNING,
+                        "Invalid readPreferences");
 
    capture_logs (true);
 
    /* zero is prohibited */
-   client = mongoc_client_new (
-      "mongodb://a/?readPreference=nearest&maxStalenessSeconds=0");
+   client = mongoc_client_new ("mongodb://a/?" MONGOC_URI_READPREFERENCE
+                               "=nearest&" MONGOC_URI_MAXSTALENESSSECONDS "=0");
 
-   ASSERT_CAPTURED_LOG ("maxStalenessSeconds=0", MONGOC_LOG_LEVEL_WARNING,
-                        "cannot be zero");
+   ASSERT_CAPTURED_LOG (
+      MONGOC_URI_MAXSTALENESSSECONDS "=0",
+      MONGOC_LOG_LEVEL_WARNING,
+      "Unsupported value for \"" MONGOC_URI_MAXSTALENESSSECONDS "\": \"0\"");
 
    ASSERT_CMPINT64 (get_max_staleness (client), ==, (int64_t) -1);
    mongoc_client_destroy (client);
 
-   client = mongoc_client_new (
-      "mongodb://a/?maxStalenessSeconds=120&readPreference=secondary");
+   client = mongoc_client_new ("mongodb://a/?" MONGOC_URI_MAXSTALENESSSECONDS
+                               "=120&" MONGOC_URI_READPREFERENCE "=secondary");
 
    ASSERT_CMPINT64 (get_max_staleness (client), ==, (int64_t) 120);
    mongoc_client_destroy (client);
 
    /* float is ignored */
    capture_logs (true);
-   ASSERT (!mongoc_client_new (
-      "mongodb://a/?readPreference=secondary&maxStalenessSeconds=10.5"));
+   ASSERT (!mongoc_client_new ("mongodb://a/?" MONGOC_URI_READPREFERENCE
+                               "=secondary&" MONGOC_URI_MAXSTALENESSSECONDS
+                               "=10.5"));
 
-   ASSERT_CAPTURED_LOG ("maxStalenessSeconds=10.5", MONGOC_LOG_LEVEL_WARNING,
-                        "Invalid maxStalenessSeconds");
+   ASSERT_CAPTURED_LOG (MONGOC_URI_MAXSTALENESSSECONDS "=10.5",
+                        MONGOC_LOG_LEVEL_WARNING,
+                        "Invalid " MONGOC_URI_MAXSTALENESSSECONDS);
 
    /* 1 is allowed, it'll be rejected once we begin server selection */
-   client = mongoc_client_new (
-      "mongodb://a/?readPreference=secondary&maxStalenessSeconds=1");
+   client =
+      mongoc_client_new ("mongodb://a/?" MONGOC_URI_READPREFERENCE
+                         "=secondary&" MONGOC_URI_MAXSTALENESSSECONDS "=1");
 
    ASSERT_EQUAL_DOUBLE (get_max_staleness (client), 1);
    mongoc_client_destroy (client);
@@ -105,14 +119,17 @@ test_mongos_max_staleness_read_pref (void)
    client = mongoc_client_new_from_uri (mock_server_get_uri (server));
    collection = mongoc_client_get_collection (client, "db", "collection");
 
-   /* count command with mode "secondary", no maxStalenessSeconds */
+   /* count command with mode "secondary", no " MONGOC_URI_MAXSTALENESSSECONDS "
+    */
    prefs = mongoc_read_prefs_new (MONGOC_READ_SECONDARY);
    mongoc_collection_set_read_prefs (collection, prefs);
-   future = future_collection_count (collection, MONGOC_QUERY_NONE,
-                                     NULL, 0, 0, NULL, &error);
+   future = future_collection_count (
+      collection, MONGOC_QUERY_NONE, NULL, 0, 0, NULL, &error);
    request = mock_server_receives_command (
-      server, "db", MONGOC_QUERY_SLAVE_OK,
-      "{'$readPreference': {'mode': 'secondary', "
+      server,
+      "db",
+      MONGOC_QUERY_SLAVE_OK,
+      "{'$" MONGOC_URI_READPREFERENCE "': {'mode': 'secondary', "
       "                     'maxStalenessSeconds': {'$exists': false}}}");
 
    mock_server_replies_simple (request, "{'ok': 1, 'n': 1}");
@@ -121,17 +138,21 @@ test_mongos_max_staleness_read_pref (void)
    request_destroy (request);
    future_destroy (future);
 
-   /* count command with mode "secondary". maxStalenessSeconds=1 is allowed by
+   /* count command with mode "secondary". " MONGOC_URI_MAXSTALENESSSECONDS "=1
+    * is allowed by
     * client, although in real life mongos will reject it */
    mongoc_read_prefs_set_max_staleness_seconds (prefs, 1);
    mongoc_collection_set_read_prefs (collection, prefs);
 
    mongoc_collection_set_read_prefs (collection, prefs);
-   future = future_collection_count (collection, MONGOC_QUERY_NONE,
-                                     NULL, 0, 0, NULL, &error);
+   future = future_collection_count (
+      collection, MONGOC_QUERY_NONE, NULL, 0, 0, NULL, &error);
    request = mock_server_receives_command (
-      server, "db", MONGOC_QUERY_SLAVE_OK,
-      "{'$readPreference': {'mode': 'secondary', 'maxStalenessSeconds': 1}}");
+      server,
+      "db",
+      MONGOC_QUERY_SLAVE_OK,
+      "{'$readPreference': {'mode': 'secondary', 'maxStalenessSeconds': 1}}",
+      NULL);
 
    mock_server_replies_simple (request, "{'ok': 1, 'n': 1}");
    ASSERT_OR_PRINT (1 == future_get_int64_t (future), error);
@@ -169,21 +190,22 @@ _test_last_write_date (bool pooled)
       client = mongoc_client_new_from_uri (uri);
       test_framework_set_ssl_opts (client);
    }
+   mongoc_uri_destroy (uri);
 
    collection = get_test_collection (client, "test_last_write_date");
-   r = mongoc_collection_insert (collection, MONGOC_INSERT_NONE,
-                                 tmp_bson ("{}"), NULL, &error);
+   r = mongoc_collection_insert_one (
+      collection, tmp_bson ("{}"), NULL, NULL, &error);
    ASSERT_OR_PRINT (r, error);
 
-   _mongoc_usleep (1000 * 1000);
+   _mongoc_usleep (2000 * 1000);
    s0 = mongoc_topology_select (client->topology, MONGOC_SS_READ, NULL, &error);
    ASSERT_OR_PRINT (s0, error);
 
-   r = mongoc_collection_insert (collection, MONGOC_INSERT_NONE,
-                                 tmp_bson ("{}"), NULL, &error);
+   r = mongoc_collection_insert_one (
+      collection, tmp_bson ("{}"), NULL, NULL, &error);
    ASSERT_OR_PRINT (r, error);
 
-   _mongoc_usleep (1000 * 1000);
+   _mongoc_usleep (2000 * 1000);
    s1 = mongoc_topology_select (client->topology, MONGOC_SS_READ, NULL, &error);
    ASSERT_OR_PRINT (s1, error);
    ASSERT_CMPINT64 (s1->last_write_date_ms, !=, (int64_t) -1);
@@ -254,7 +276,6 @@ _test_last_write_date_absent (bool pooled)
 }
 
 
-
 static void
 test_last_write_date_absent (void *ctx)
 {
@@ -275,28 +296,42 @@ test_all_spec_tests (TestSuite *suite)
    char resolved[PATH_MAX];
 
    ASSERT (realpath (JSON_DIR "/max_staleness", resolved));
-   install_json_test_suite (suite, resolved,
-                            &test_server_selection_logic_cb);
+   install_json_test_suite (suite, resolved, &test_server_selection_logic_cb);
 }
 
 void
 test_client_max_staleness_install (TestSuite *suite)
 {
    test_all_spec_tests (suite);
-   TestSuite_Add (suite, "/Client/max_staleness",
-                  test_mongoc_client_max_staleness);
-   TestSuite_Add (suite, "/Client/max_staleness/mongos",
-                  test_mongos_max_staleness_read_pref);
-   TestSuite_AddFull (suite, "/Client/last_write_date",
-                      test_last_write_date, NULL, NULL,
-                      test_framework_skip_if_not_rs_version_5);
-   TestSuite_AddFull (suite, "/Client/last_write_date/pooled",
-                      test_last_write_date_pooled, NULL, NULL,
-                      test_framework_skip_if_not_rs_version_5);
-   TestSuite_AddFull (suite, "/Client/last_write_date_absent",
-                      test_last_write_date_absent, NULL, NULL,
+   TestSuite_Add (
+      suite, "/Client/max_staleness", test_mongoc_client_max_staleness);
+   TestSuite_AddMockServerTest (suite,
+                                "/Client/max_staleness/mongos",
+                                test_mongos_max_staleness_read_pref);
+   TestSuite_AddFull (suite,
+                      "/Client/last_write_date",
+                      test_last_write_date,
+                      NULL,
+                      NULL,
+                      test_framework_skip_if_not_rs_version_5,
+                      test_framework_skip_if_slow);
+   TestSuite_AddFull (suite,
+                      "/Client/last_write_date/pooled",
+                      test_last_write_date_pooled,
+                      NULL,
+                      NULL,
+                      test_framework_skip_if_not_rs_version_5,
+                      test_framework_skip_if_slow);
+   TestSuite_AddFull (suite,
+                      "/Client/last_write_date_absent",
+                      test_last_write_date_absent,
+                      NULL,
+                      NULL,
                       test_framework_skip_if_rs_version_5);
-   TestSuite_AddFull (suite, "/Client/last_write_date_absent/pooled",
-                      test_last_write_date_absent_pooled, NULL, NULL,
+   TestSuite_AddFull (suite,
+                      "/Client/last_write_date_absent/pooled",
+                      test_last_write_date_absent_pooled,
+                      NULL,
+                      NULL,
                       test_framework_skip_if_rs_version_5);
 }
