@@ -2,6 +2,7 @@
 #include <mongoc-util-private.h>
 
 #include "mongoc-client-private.h"
+#include "mongoc-client-pool-private.h"
 #include "utlist.h"
 
 #include "mock_server/future.h"
@@ -16,8 +17,7 @@
 
 
 static const mongoc_topology_scanner_node_t *
-get_node (mongoc_topology_t *topology,
-          const char *host_and_port)
+get_node (mongoc_topology_t *topology, const char *host_and_port)
 {
    const mongoc_topology_scanner_t *ts;
    const mongoc_topology_scanner_node_t *node;
@@ -43,10 +43,7 @@ get_node (mongoc_topology_t *topology,
 
 
 void
-rs_response_to_ismaster (mock_server_t *server,
-                         bool primary,
-                         bool has_tags,
-                         ...)
+rs_response_to_ismaster (mock_server_t *server, bool primary, int has_tags, ...)
 {
    va_list ap;
    bson_string_t *hosts;
@@ -66,25 +63,25 @@ rs_response_to_ismaster (mock_server_t *server,
          bson_string_append (hosts, ",");
       }
 
-      bson_string_append_printf (hosts,
-                                 "'%s'",
-                                 mock_server_get_host_and_port (host));
+      bson_string_append_printf (
+         hosts, "'%s'", mock_server_get_host_and_port (host));
    }
 
    va_end (ap);
 
-   ismaster_response = bson_strdup_printf (
-      "{'ok': 1, "
-      " 'setName': 'rs',"
-      " 'ismaster': %s,"
-      " 'secondary': %s,"
-      " 'tags': {%s},"
-      " 'hosts': [%s]"
-      "}",
-      primary ? "true" : "false",
-      primary ? "false" : "true",
-      has_tags ? "'key': 'value'" : "",
-      hosts->str);
+   ismaster_response = bson_strdup_printf ("{'ok': 1, "
+                                           " 'setName': 'rs',"
+                                           " 'ismaster': %s,"
+                                           " 'secondary': %s,"
+                                           " 'tags': {%s},"
+                                           " 'minWireVersion': 2,"
+                                           " 'maxWireVersion': 5,"
+                                           " 'hosts': [%s]"
+                                           "}",
+                                           primary ? "true" : "false",
+                                           primary ? "false" : "true",
+                                           has_tags ? "'key': 'value'" : "",
+                                           hosts->str);
 
    mock_server_auto_ismaster (server, ismaster_response);
 
@@ -106,8 +103,8 @@ selects_server (mongoc_client_t *client,
    mongoc_server_description_t *sd;
    bool result;
 
-   sd = mongoc_topology_select (client->topology, MONGOC_SS_READ,
-                                read_prefs, &error);
+   sd = mongoc_topology_select (
+      client->topology, MONGOC_SS_READ, read_prefs, &error);
 
    if (!sd) {
       fprintf (stderr, "%s\n", error.message);
@@ -132,11 +129,15 @@ _test_topology_reconcile_rs (bool pooled)
    mongoc_uri_t *uri;
    mongoc_client_pool_t *pool = NULL;
    mongoc_client_t *client;
-   debug_stream_stats_t debug_stream_stats = { 0 };
+   debug_stream_stats_t debug_stream_stats = {0};
    mongoc_read_prefs_t *secondary_read_prefs;
    mongoc_read_prefs_t *primary_read_prefs;
    mongoc_read_prefs_t *tag_read_prefs;
 
+   if (!TestSuite_CheckMockServerAllowed ()) {
+      return;
+   }
+
    server0 = mock_server_new ();
    server1 = mock_server_new ();
    mock_server_run (server0);
@@ -148,9 +149,8 @@ _test_topology_reconcile_rs (bool pooled)
    RS_RESPONSE_TO_ISMASTER (server1, true, false, server0, server1);
 
    /* provide secondary in seed list */
-   uri_str = bson_strdup_printf (
-      "mongodb://%s/?replicaSet=rs",
-      mock_server_get_host_and_port (server0));
+   uri_str = bson_strdup_printf ("mongodb://%s/?replicaSet=rs",
+                                 mock_server_get_host_and_port (server0));
 
    uri = mongoc_uri_new (uri_str);
 
@@ -173,22 +173,22 @@ _test_topology_reconcile_rs (bool pooled)
    /*
     * server0 is selected, server1 is discovered and added to scanner.
     */
-   assert (selects_server (client, secondary_read_prefs, server0));
-   assert (get_node (client->topology,
-                     mock_server_get_host_and_port (server1)));
+   BSON_ASSERT (selects_server (client, secondary_read_prefs, server0));
+   BSON_ASSERT (
+      get_node (client->topology, mock_server_get_host_and_port (server1)));
 
    /*
     * select again with mode "primary": server1 is selected.
     */
-   assert (selects_server (client, primary_read_prefs, server1));
+   BSON_ASSERT (selects_server (client, primary_read_prefs, server1));
 
    /*
     * remove server1 from set. server0 is the primary, with tags.
     */
-   RS_RESPONSE_TO_ISMASTER (server0, true, true, server0);  /* server1 absent */
+   RS_RESPONSE_TO_ISMASTER (server0, true, true, server0); /* server1 absent */
 
-   assert (selects_server (client, tag_read_prefs, server0));
-   assert (!client->topology->stale);
+   BSON_ASSERT (selects_server (client, tag_read_prefs, server0));
+   BSON_ASSERT (!client->topology->stale);
 
    if (!pooled) {
       ASSERT_CMPINT (1, ==, debug_stream_stats.n_failed);
@@ -200,7 +200,7 @@ _test_topology_reconcile_rs (bool pooled)
    RS_RESPONSE_TO_ISMASTER (server0, true, true, server0, server1);
    RS_RESPONSE_TO_ISMASTER (server1, false, false, server0, server1);
 
-   assert (selects_server (client, secondary_read_prefs, server1));
+   BSON_ASSERT (selects_server (client, secondary_read_prefs, server1));
 
    if (!pooled) {
       /* no additional failed streams */
@@ -255,16 +255,19 @@ _test_topology_reconcile_sharded (bool pooled)
    char *secondary_response;
    mongoc_server_description_t *sd;
 
+   if (!TestSuite_CheckMockServerAllowed ()) {
+      return;
+   }
+
    mongos = mock_server_new ();
    secondary = mock_server_new ();
    mock_server_run (mongos);
    mock_server_run (secondary);
 
    /* provide both servers in seed list */
-   uri_str = bson_strdup_printf (
-      "mongodb://%s,%s",
-      mock_server_get_host_and_port (mongos),
-      mock_server_get_host_and_port (secondary));
+   uri_str = bson_strdup_printf ("mongodb://%s,%s",
+                                 mock_server_get_host_and_port (mongos),
+                                 mock_server_get_host_and_port (secondary));
 
    uri = mongoc_uri_new (uri_str);
 
@@ -276,14 +279,14 @@ _test_topology_reconcile_sharded (bool pooled)
    }
 
    primary_read_prefs = mongoc_read_prefs_new (MONGOC_READ_PRIMARY);
-   future = future_topology_select (client->topology, MONGOC_SS_READ,
-                                    primary_read_prefs, &error);
+   future = future_topology_select (
+      client->topology, MONGOC_SS_READ, primary_read_prefs, &error);
 
    /* mongos */
    request = mock_server_receives_ismaster (mongos);
-   mock_server_replies_simple (
-      request,
-      "{'ok': 1, 'ismaster': true, 'msg': 'isdbgrid'}");
+   mock_server_replies_simple (request,
+                               "{'ok': 1, 'ismaster': true, 'minWireVersion': "
+                               "2, 'maxWireVersion': 5, 'msg': 'isdbgrid'}");
 
    request_destroy (request);
 
@@ -292,15 +295,17 @@ _test_topology_reconcile_sharded (bool pooled)
 
    /* replica set secondary - topology removes it */
    request = mock_server_receives_ismaster (secondary);
-   secondary_response = bson_strdup_printf (
-      "{'ok': 1, "
-      " 'setName': 'rs',"
-      " 'ismaster': false,"
-      " 'secondary': true,"
-      " 'hosts': ['%s', '%s']"
-      "}",
-      mock_server_get_host_and_port (mongos),
-      mock_server_get_host_and_port (secondary));
+   secondary_response =
+      bson_strdup_printf ("{'ok': 1, "
+                          " 'setName': 'rs',"
+                          " 'ismaster': false,"
+                          " 'secondary': true,"
+                          " 'minWireVersion': 2,"
+                          " 'maxWireVersion': 5,"
+                          " 'hosts': ['%s', '%s']"
+                          "}",
+                          mock_server_get_host_and_port (mongos),
+                          mock_server_get_host_and_port (secondary));
 
    mock_server_replies_simple (request, secondary_response);
 
@@ -317,13 +322,13 @@ _test_topology_reconcile_sharded (bool pooled)
       /* wait a second for scanner thread to remove secondary */
       int64_t start = bson_get_monotonic_time ();
       while (get_node (client->topology,
-                       mock_server_get_host_and_port (secondary)))
-      {
-         assert (bson_get_monotonic_time () - start < 1000000);
+                       mock_server_get_host_and_port (secondary))) {
+         ASSERT_CMPTIME ((int) (bson_get_monotonic_time () - start),
+                         (int) 1000000);
       }
    } else {
-      assert (!get_node (client->topology,
-                         mock_server_get_host_and_port (secondary)));
+      BSON_ASSERT (!get_node (client->topology,
+                              mock_server_get_host_and_port (secondary)));
    }
 
    mongoc_server_description_destroy (sd);
@@ -359,15 +364,128 @@ test_topology_reconcile_sharded_pooled (void)
 }
 
 
+typedef struct {
+   mongoc_mutex_t mutex;
+   size_t servers;
+} reconcile_test_data_t;
+
+
+static void
+server_opening (const mongoc_apm_server_opening_t *event)
+{
+   reconcile_test_data_t *data = (reconcile_test_data_t *) event->context;
+
+   mongoc_mutex_lock (&data->mutex);
+   data->servers++;
+   mongoc_mutex_unlock (&data->mutex);
+}
+
+
+static void
+test_topology_reconcile_from_handshake (void *ctx)
+{
+   reconcile_test_data_t data;
+   mongoc_apm_callbacks_t *callbacks;
+   char *host;
+   uint16_t port;
+   char *replset_name;
+   char *uri_str;
+   mongoc_uri_t *uri;
+   mongoc_client_pool_t *pool;
+   mongoc_topology_t *topology;
+   mongoc_client_t *client;
+   bool r;
+   bson_error_t error;
+
+   mongoc_mutex_init (&data.mutex);
+   data.servers = 0;
+
+   callbacks = mongoc_apm_callbacks_new ();
+
+   /* single seed - not the full test_framework_get_uri */
+   host = test_framework_get_host ();
+   port = test_framework_get_port ();
+   replset_name = test_framework_replset_name ();
+   uri_str = bson_strdup_printf (
+      "mongodb://%s:%hu/?replicaSet=%s", host, port, replset_name);
+
+   uri = mongoc_uri_new (uri_str);
+   pool = mongoc_client_pool_new (uri);
+   mongoc_apm_set_server_opening_cb (callbacks, server_opening);
+   mongoc_client_pool_set_apm_callbacks (pool, callbacks, &data);
+   test_framework_set_pool_ssl_opts (pool);
+
+   /* make the bg thread lose the data race: prevent it starting by pretending
+    * it already has */
+   topology = _mongoc_client_pool_get_topology (pool);
+   topology->scanner_state = MONGOC_TOPOLOGY_SCANNER_BG_RUNNING;
+
+   /* ordinarily would start bg thread */
+   client = mongoc_client_pool_pop (pool);
+
+   /* command in the foreground (ismaster, just because it doesn't need auth) */
+   r = mongoc_client_read_command_with_opts (client,
+                                             "admin",
+                                             tmp_bson ("{'ismaster': 1}"),
+                                             NULL,
+                                             tmp_bson ("{'serverId': 1}"),
+                                             NULL,
+                                             &error);
+
+   ASSERT_OR_PRINT (r, error);
+
+   /* If CDRIVER-2073 isn't fixed, then when we discovered the other replicas
+    * during the handshake in the foreground, we also set the new scanner nodes'
+    * "cmd" fields. The thread will die at assert (!node->cmd) once it starts.
+    */
+   topology->scanner_state = MONGOC_TOPOLOGY_SCANNER_OFF;
+   mongoc_client_pool_push (pool, client);
+   client = mongoc_client_pool_pop (pool);
+
+   /* no serverId, waits for topology scan */
+   r = mongoc_client_read_command_with_opts (
+      client, "admin", tmp_bson ("{'ismaster': 1}"), NULL, NULL, NULL, &error);
+
+   ASSERT_OR_PRINT (r, error);
+   mongoc_mutex_lock (&data.mutex);
+   ASSERT_CMPSIZE_T (data.servers, ==, test_framework_replset_member_count ());
+   mongoc_mutex_unlock (&data.mutex);
+
+   mongoc_client_pool_push (pool, client);
+   mongoc_client_pool_destroy (pool);
+   mongoc_apm_callbacks_destroy (callbacks);
+   mongoc_uri_destroy (uri);
+   bson_free (uri_str);
+   bson_free (replset_name);
+   bson_free (host);
+}
+
+
 void
 test_topology_reconcile_install (TestSuite *suite)
 {
-   TestSuite_AddFull (suite, "/TOPOLOGY/reconcile/rs/pooled",
-                  test_topology_reconcile_rs_pooled, NULL, NULL, test_framework_skip_if_slow);
-   TestSuite_AddFull (suite, "/TOPOLOGY/reconcile/rs/single",
-                  test_topology_reconcile_rs_single, NULL, NULL, test_framework_skip_if_slow);
-   TestSuite_Add (suite, "/TOPOLOGY/reconcile/sharded/pooled",
+   TestSuite_AddFull (suite,
+                      "/TOPOLOGY/reconcile/rs/pooled",
+                      test_topology_reconcile_rs_pooled,
+                      NULL,
+                      NULL,
+                      test_framework_skip_if_slow);
+   TestSuite_AddFull (suite,
+                      "/TOPOLOGY/reconcile/rs/single",
+                      test_topology_reconcile_rs_single,
+                      NULL,
+                      NULL,
+                      test_framework_skip_if_slow);
+   TestSuite_Add (suite,
+                  "/TOPOLOGY/reconcile/sharded/pooled",
                   test_topology_reconcile_sharded_pooled);
-   TestSuite_Add (suite, "/TOPOLOGY/reconcile/sharded/single",
+   TestSuite_Add (suite,
+                  "/TOPOLOGY/reconcile/sharded/single",
                   test_topology_reconcile_sharded_single);
+   TestSuite_AddFull (suite,
+                      "/TOPOLOGY/reconcile/from_handshake",
+                      test_topology_reconcile_from_handshake,
+                      NULL,
+                      NULL,
+                      test_framework_skip_if_not_replset);
 }
